@@ -1,31 +1,29 @@
+import nonebot
 from random import sample, shuffle
 from pathlib import Path 
 import os
-import nonebot
 
-global_config = nonebot.get_driver().config
-TAROT_PATH = os.path.join(os.path.dirname(__file__), "resource") if not global_config.tarot_path else global_config.tarot_path
+_TAROT_PATH = nonebot.get_driver().config.tarot_path
+DEFAULT_PATH = os.path.join(os.path.dirname(__file__), "resource")
+TAROT_PATH = DEFAULT_PATH if not _TAROT_PATH else _TAROT_PATH
 
 class Cards() :
     def __init__(self, num: int):
-        '''
-            为了模拟抽牌过程，所以会将卡组打乱，然后从小到大进行抽牌
-            所以稍微牺牲点性能没问题的对吧！
-        '''
+        #为了模拟抽牌过程，所以会将卡组打乱，然后从小到大进行抽牌
+        #所以稍微牺牲点性能没问题的对吧！
         names = list(cards.keys())
         shuffle(names)
-        self.selected = [names[card_id] for card_id in sample(range(0,78), num)]
+        self.selected = [names[card_id] for card_id in sample(range(0,78),num)]
         self.showed = 0
 
-    # 揭示牌（玄学当然要有仪式感！）
+    #揭示牌（玄学当然要有仪式感！）
     def reveal(self):
-        card_key = self.selected[self.showed]               # 牌名
-        card_meaning = cards[card_key]                      # 含义
-        image_file = Path(TAROT_PATH) / (card_key + ".jpg") # 图片路径
+        card_key = self.selected[self.showed] #牌名
+        card_meaning = cards[card_key] #含义
+        image_file = Path(TAROT_PATH) / (card_key + ".jpg") #图片路径
         self.showed += 1
         return card_key, card_meaning, image_file
 
-
 #不是最终版本。从愚者开始是改过的含义。前边的之后会改。——lolifish
 cards = {
     "圣杯1": "家庭生活之幸福，别的牌可给予其更多内涵，如宾客来访、宴席、吵架",
@@ -113,4 +111,4 @@ meanings = {
     "第二张牌": "代表问题导致的局面",
     "第三张牌": "表示困难可能有的解决方法",
     "切牌": "表示问卜者的主观想法",
-}
+}
\ No newline at end of file
